<?php
/**
 * Plugin Name: Sectional Comments
 * Plugin URI: https://joevics.pro/sectional-comments
 * Description: Transform your WordPress comments into dynamic discussion hubs with multiple comment sections per page. Features block editor integration, shortcode support, and advanced moderation tools.
 * Version: 1.1.0
 * Requires at least: 5.8
 * Requires PHP: 7.4
 * Author: Victor Joshua
 * Author URI: https://joevics.pro
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: sectional-comments
 * Domain Path: /languages
 *
 * @package SectionalComments
 * @author Victor Joshua
 * @copyright 2024 Victor Joshua
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit;
}
// Add admin menu items
function sectional_comments_admin_menu() {
    // Add main menu item
    add_menu_page(
        'Sectional Comments',
        'Sectional Comments',
        'manage_options',
        'sectional-comments',
        'sectional_comments_dashboard_page',
        'dashicons-admin-comments',
        30
    );

    // Add sub-menu items
    add_submenu_page(
        'sectional-comments',
        'Dashboard',
        'Dashboard',
        'manage_options',
        'sectional-comments',
        'sectional_comments_dashboard_page'
    );

    add_submenu_page(
        'sectional-comments',
        'Settings',
        'Settings',
        'manage_options',
        'sectional-comments-settings',
        'sectional_comments_settings_page'
    );

    add_submenu_page(
        'sectional-comments',
        'Comment Boxes',
        'Comment Boxes',
        'manage_options',
        'sectional-comments-boxes',
        'sectional_comments_boxes_page'
    );
}
add_action('admin_menu', 'sectional_comments_admin_menu');

// Enqueue admin scripts and styles
function sectional_comments_admin_enqueue($hook) {
    if (strpos($hook, 'sectional-comments') !== false) {
        wp_enqueue_style(
            'sectional-comments-admin',
            plugins_url('css/admin-style.css', __FILE__),
            array(),
            filemtime(plugin_dir_path(__FILE__) . 'css/admin-style.css')
        );
        wp_enqueue_script(
            'sectional-comments-admin',
            plugins_url('js/admin-script.js', __FILE__),
            array('jquery'),
            filemtime(plugin_dir_path(__FILE__) . 'js/admin-script.js'),
            true
        );
        wp_localize_script('sectional-comments-admin', 'sectionalCommentsAdmin', array(
            'ajax_url' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('sectional_comments_admin_nonce')
        ));
    }
}
add_action('admin_enqueue_scripts', 'sectional_comments_admin_enqueue');

// Enqueue block editor assets
function sectional_comments_enqueue_block_editor_assets() {
    wp_enqueue_script(
        'sectional-comments-block',
        plugins_url('build/index.js', __FILE__),
        array('wp-blocks', 'wp-element', 'wp-editor'),
        filemtime(plugin_dir_path(__FILE__) . 'build/index.js')
    );
}
add_action('enqueue_block_editor_assets', 'sectional_comments_enqueue_block_editor_assets');

function sectional_comments_enqueue_styles() {
    wp_enqueue_style(
        'sectional-comments-style',
        plugins_url('style.css', __FILE__),
        array(),
        filemtime(plugin_dir_path(__FILE__) . 'style.css')
    );
}
add_action('wp_enqueue_scripts', 'sectional_comments_enqueue_styles');

// Enqueue frontend scripts
function sectional_comments_enqueue_frontend_scripts() {
    wp_enqueue_script(
        'sectional-comments-frontend',
        plugins_url('js/frontend.js', __FILE__),
        array('jquery'),
        filemtime(plugin_dir_path(__FILE__) . 'js/frontend.js'),
        true
    );
    wp_localize_script('sectional-comments-frontend', 'sectionalCommentsAjax', array(
        'ajax_url' => admin_url('admin-ajax.php'),
        'nonce' => wp_create_nonce('sectional_comments_nonce')
    ));
}
add_action('wp_enqueue_scripts', 'sectional_comments_enqueue_frontend_scripts');

// Dashboard page callback
function sectional_comments_dashboard_page() {
    // Get statistics
    $total_boxes = get_comment_boxes_count();
    $total_comments = get_total_comments_count();
    $recent_comments = get_recent_comments();
    $active_boxes = get_active_comment_boxes();
    ?>
    <div class="wrap sectional-comments-admin">
        <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
        
        <!-- Statistics Cards -->
        <div class="sc-stats-grid">
            <div class="sc-stat-card">
                <div class="sc-stat-icon dashicons dashicons-admin-comments"></div>
                <div class="sc-stat-content">
                    <h3>Total Comments</h3>
                    <p class="sc-stat-number"><?php echo esc_html($total_comments); ?></p>
                </div>
            </div>
            
            <div class="sc-stat-card">
                <div class="sc-stat-icon dashicons dashicons-feedback"></div>
                <div class="sc-stat-content">
                    <h3>Comment Boxes</h3>
                    <p class="sc-stat-number"><?php echo esc_html($total_boxes); ?></p>
                </div>
            </div>
            
            <div class="sc-stat-card">
                <div class="sc-stat-icon dashicons dashicons-chart-bar"></div>
                <div class="sc-stat-content">
                    <h3>Active Today</h3>
                    <p class="sc-stat-number"><?php echo esc_html($active_boxes['today']); ?></p>
                </div>
            </div>
        </div>

        <!-- Recent Comments Section -->
        <div class="sc-recent-comments">
            <h2>Recent Comments</h2>
            <div class="sc-table-container">
                <table class="sc-table">
                    <thead>
                        <tr>
                            <th>Comment</th>
                            <th>Author</th>
                            <th>Section</th>
                            <th>Date</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($recent_comments as $comment): ?>
                            <tr>
                                <td><?php echo esc_html(wp_trim_words($comment->comment_content, 10)); ?></td>
                                <td><?php echo esc_html($comment->comment_author); ?></td>
                                <td><?php echo esc_html(get_comment_meta($comment->comment_ID, 'section_id', true)); ?></td>
                                <td><?php echo esc_html(human_time_diff(strtotime($comment->comment_date))); ?> ago</td>
                                <td>
    <div class="sc-comment-actions">
        <?php if (!$comment->comment_approved): ?>
            <button class="sc-button sc-comment-action" 
                    data-action="approve" 
                    data-comment-id="<?php echo esc_attr($comment->comment_ID); ?>">
                Approve
            </button>
        <?php endif; ?>
        <button class="sc-button sc-comment-action" 
                data-action="edit" 
                data-comment-id="<?php echo esc_attr($comment->comment_ID); ?>">
            Edit
        </button>
        <button class="sc-button sc-comment-action sc-button-delete" 
                data-action="delete" 
                data-comment-id="<?php echo esc_attr($comment->comment_ID); ?>">
            Delete
        </button>
        <a href="<?php echo esc_url(get_comment_link($comment->comment_ID)); ?>" 
           class="sc-button sc-comment-action" 
           target="_blank">
            View
        </a>
    </div>
     </td>                            
    </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Active Comment Boxes Section -->
        <div class="sc-active-boxes">
            <h2>Active Comment Boxes</h2>
            <div class="sc-boxes-grid">
                <?php foreach ($active_boxes['boxes'] as $box): ?>
                    <div class="sc-box-card">
                        <h3><?php echo esc_html($box->section_id); ?></h3>
                        <p>Comments: <?php echo esc_html($box->comment_count); ?></p>
                        <p>Last activity: <?php echo esc_html(human_time_diff(strtotime($box->last_activity))); ?> ago</p>
                        <a href="<?php echo esc_url(admin_url('admin.php?page=sectional-comments-boxes&section=' . $box->section_id)); ?>" class="sc-button">
                            View Details
                        </a>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
    </div>
    <?php
}

function handle_comment_approval() {
    check_ajax_referer('sectional_comments_admin_nonce', 'nonce');
    $comment_id = intval($_POST['comment_id']);
    wp_set_comment_status($comment_id, 'approve');
    wp_send_json_success();
}
add_action('wp_ajax_approve_comment', 'handle_comment_approval');

function handle_comment_edit() {
    check_ajax_referer('sectional_comments_admin_nonce', 'nonce');
    $comment_id = intval($_POST['comment_id']);
    $content = sanitize_textarea_field($_POST['content']);
    wp_update_comment(array(
        'comment_ID' => $comment_id,
        'comment_content' => $content
    ));
    wp_send_json_success();
}
add_action('wp_ajax_edit_comment', 'handle_comment_edit');

function handle_comment_deletion() {
    check_ajax_referer('sectional_comments_admin_nonce', 'nonce');
    $comment_id = intval($_POST['comment_id']);
    wp_delete_comment($comment_id, true);
    wp_send_json_success();
}
add_action('wp_ajax_delete_comment', 'handle_comment_deletion');
// Helper functions for dashboard
function get_comment_boxes_count() {
    global $wpdb;
    $count = $wpdb->get_var("
        SELECT COUNT(DISTINCT meta_value) 
        FROM $wpdb->commentmeta 
        WHERE meta_key = 'section_id'
    ");
    return $count ? $count : 0;
}

function get_total_comments_count() {
    global $wpdb;
    $count = $wpdb->get_var("
        SELECT COUNT(*) 
        FROM $wpdb->comments 
        WHERE comment_type = 'sectional_comment'
    ");
    return $count ? $count : 0;
}

function get_recent_comments($limit = 10) {
    $comments = get_comments(array(
        'type' => 'sectional_comment',
        'number' => $limit,
        'order' => 'DESC',
        'orderby' => 'comment_date_gmt'
    ));

    foreach ($comments as &$comment) {
        $comment->actions = array(
            'approve' => !$comment->comment_approved,
            'edit' => true,
            'delete' => true,
            'view' => true
        );
    }

    return $comments;
}

function get_active_comment_boxes() {
    global $wpdb;
    
    // Get boxes with activity in last 24 hours
    $today_active = $wpdb->get_var("
        SELECT COUNT(DISTINCT cm.meta_value)
        FROM $wpdb->commentmeta cm
        JOIN $wpdb->comments c ON c.comment_ID = cm.comment_id
        WHERE cm.meta_key = 'section_id'
        AND c.comment_date >= DATE_SUB(NOW(), INTERVAL 24 HOUR)
    ");

    // Get most active boxes
    $active_boxes = $wpdb->get_results("
        SELECT 
            cm.meta_value as section_id,
            COUNT(*) as comment_count,
            MAX(c.comment_date) as last_activity
        FROM $wpdb->commentmeta cm
        JOIN $wpdb->comments c ON c.comment_ID = cm.comment_id
        WHERE cm.meta_key = 'section_id'
        GROUP BY cm.meta_value
        ORDER BY last_activity DESC
        LIMIT 6
    ");

    return array(
        'today' => $today_active ? $today_active : 0,
        'boxes' => $active_boxes ? $active_boxes : array()
    );
}

// Register plugin settings
function sectional_comments_register_settings() {
    // Register a new section
    add_settings_section(
        'sectional_comments_general_settings',
        'General Settings',
        'sectional_comments_general_settings_callback',
        'sectional-comments-settings'
    );

    // Register settings
    register_setting('sectional_comments_settings', 'sc_auto_approve_comments');
    register_setting('sectional_comments_settings', 'sc_allow_anonymous');
    register_setting('sectional_comments_settings', 'sc_comments_per_page');
    register_setting('sectional_comments_settings', 'sc_notification_email');
    register_setting('sectional_comments_settings', 'sc_moderate_links');
    
    // Add settings fields
    add_settings_field(
        'sc_auto_approve_comments',
        'Auto-Approve Comments',
        'sectional_comments_checkbox_callback',
        'sectional-comments-settings',
        'sectional_comments_general_settings',
        array(
            'id' => 'sc_auto_approve_comments',
            'description' => 'Automatically approve new comments'
        )
    );

    add_settings_field(
        'sc_allow_anonymous',
        'Allow Anonymous Comments',
        'sectional_comments_checkbox_callback',
        'sectional-comments-settings',
        'sectional_comments_general_settings',
        array(
            'id' => 'sc_allow_anonymous',
            'description' => 'Allow users to comment without logging in'
        )
    );

    add_settings_field(
        'sc_comments_per_page',
        'Comments Per Page',
        'sectional_comments_number_callback',
        'sectional-comments-settings',
        'sectional_comments_general_settings',
        array(
            'id' => 'sc_comments_per_page',
            'description' => 'Number of comments to show per page',
            'default' => 5,
            'min' => 1,
            'max' => 50
        )
    );

    add_settings_field(
        'sc_notification_email',
        'Notification Email',
        'sectional_comments_email_callback',
        'sectional-comments-settings',
        'sectional_comments_general_settings',
        array(
            'id' => 'sc_notification_email',
            'description' => 'Email address for comment notifications'
        )
    );

    add_settings_field(
        'sc_moderate_links',
        'Moderate Comments with Links',
        'sectional_comments_checkbox_callback',
        'sectional-comments-settings',
        'sectional_comments_general_settings',
        array(
            'id' => 'sc_moderate_links',
            'description' => 'Automatically moderate comments containing links'
        )
    );
}
add_action('admin_init', 'sectional_comments_register_settings');

// Settings section callback
function sectional_comments_general_settings_callback() {
    echo '<p>Configure the general settings for Sectional Comments plugin.</p>';
}

// Checkbox field callback
function sectional_comments_checkbox_callback($args) {
    $option = get_option($args['id']);
    ?>
    <label class="sc-switch">
        <input type="checkbox" 
               id="<?php echo esc_attr($args['id']); ?>"
               name="<?php echo esc_attr($args['id']); ?>"
               value="1"
               <?php checked(1, $option, true); ?>>
        <span class="sc-slider"></span>
    </label>
    <p class="description"><?php echo esc_html($args['description']); ?></p>
    <?php
}

// Number field callback
function sectional_comments_number_callback($args) {
    $option = get_option($args['id'], $args['default']);
    ?>
    <input type="number"
           id="<?php echo esc_attr($args['id']); ?>"
           name="<?php echo esc_attr($args['id']); ?>"
           value="<?php echo esc_attr($option); ?>"
           min="<?php echo esc_attr($args['min']); ?>"
           max="<?php echo esc_attr($args['max']); ?>"
           class="sc-number-input">
    <p class="description"><?php echo esc_html($args['description']); ?></p>
    <?php
}

// Email field callback
function sectional_comments_email_callback($args) {
    $option = get_option($args['id'], get_option('admin_email'));
    ?>
    <input type="email"
           id="<?php echo esc_attr($args['id']); ?>"
           name="<?php echo esc_attr($args['id']); ?>"
           value="<?php echo esc_attr($option); ?>"
           class="sc-email-input">
    <p class="description"><?php echo esc_html($args['description']); ?></p>
    <?php
}

// Settings page callback
function sectional_comments_settings_page() {
   // Check user capabilities
   if (!current_user_can('manage_options')) {
       return;
   }

   // Show success message if settings were updated
   if (isset($_GET['settings-updated'])) {
       add_settings_error(
           'sectional_comments_messages',
           'sectional_comments_message',
           'Settings Saved',
           'updated'
       );
   }
   ?>
   <div class="wrap sectional-comments-admin">
       <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
       <?php settings_errors('sectional_comments_messages'); ?>

       <form method="post" action="options.php" class="sc-settings-form">
           <?php
           settings_fields('sectional_comments_settings');
           do_settings_sections('sectional-comments-settings');
           submit_button('Save Settings');
           ?>
       </form>

       <div class="sc-settings-sidebar">
           <div class="sc-settings-card">
               <h3>Need Help?</h3>
               <p>Check out our documentation for detailed instructions on how to use Sectional Comments.</p>
               <a href="https://joevics.pro/sectional-comments/documentation" class="sc-button">View Documentation</a>
           </div>
           
           <div class="sc-settings-card">
               <h3>Quick Tips</h3>
               <ul>
                   <li>Enable auto-approval for faster comment display</li>
                   <li>Set up email notifications to stay informed</li>
                   <li>Moderate links to prevent spam</li>
               </ul>
           </div>
       </div>
   </div>
   <?php
}

// Comment boxes page callback
function sectional_comments_boxes_page() {
   // Get all comment boxes
   global $wpdb;
   $boxes = $wpdb->get_results("
       SELECT 
           cm.meta_value as section_id,
           COUNT(*) as comment_count,
           MAX(c.comment_date) as last_activity,
           MIN(c.comment_date) as first_activity
       FROM {$wpdb->commentmeta} cm
       JOIN {$wpdb->comments} c ON c.comment_ID = cm.comment_id
       WHERE cm.meta_key = 'section_id'
       GROUP BY cm.meta_value
       ORDER BY last_activity DESC
   ");

   ?>
   <div class="wrap sectional-comments-admin">
       <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
       
       <!-- Search and Filter Section -->
       <div class="sc-filter-section">
           <input type="text" id="sc-search-boxes" placeholder="Search comment boxes..." class="sc-search-input">
           <select id="sc-sort-boxes" class="sc-select">
               <option value="latest">Latest Activity</option>
               <option value="oldest">Oldest Activity</option>
               <option value="most-comments">Most Comments</option>
               <option value="least-comments">Least Comments</option>
           </select>
       </div>

       <!-- Comment Boxes Grid -->
       <div class="sc-boxes-container">
           <?php foreach ($boxes as $box): ?>
               <div class="sc-box-detail-card" data-section-id="<?php echo esc_attr($box->section_id); ?>">
                   <div class="sc-box-header">
                       <h3><?php echo esc_html($box->section_id); ?></h3>
                       <span class="sc-comment-count"><?php echo esc_html($box->comment_count); ?> comments</span>
                   </div>
                   
                   <div class="sc-box-stats">
                       <div class="sc-stat">
                           <span class="sc-stat-label">First Comment:</span>
                           <span class="sc-stat-value"><?php echo esc_html(human_time_diff(strtotime($box->first_activity))); ?> ago</span>
                       </div>
                       <div class="sc-stat">
                           <span class="sc-stat-label">Latest Activity:</span>
                           <span class="sc-stat-value"><?php echo esc_html(human_time_diff(strtotime($box->last_activity))); ?> ago</span>
                       </div>
                   </div>

    <div class="sc-box-actions">
        <a href="<?php echo esc_url(admin_url('admin.php?page=sectional-comments&view=comments&section=' . $box->section_id)); ?>" 
           class="sc-button sc-button-view">
            View Comments
        </a>
        <button class="sc-button sc-button-delete" 
                data-section-id="<?php echo esc_attr($box->section_id); ?>">
            Delete Box
        </button>
    </div>
               </div>
           <?php endforeach; ?>
       </div>

       <!-- Comments Modal -->
       <div id="sc-comments-modal" class="sc-modal">
           <div class="sc-modal-content">
               <span class="sc-modal-close">&times;</span>
               <h2 class="sc-modal-title">Comments for <span id="sc-modal-section-id"></span></h2>
               <div class="sc-modal-body">
                   <!-- Comments will be loaded here -->
               </div>
           </div>
       </div>
   </div>
   <?php
}

// Handle comment submission
function handle_submit_comment() {
   if (!check_ajax_referer('sectional_comments_nonce', 'nonce', false)) {
       wp_send_json_error(array('message' => 'Invalid nonce'));
       return;
   }
   
   if (!isset($_POST['section_id']) || !isset($_POST['comment'])) {
       wp_send_json_error(array('message' => 'Missing required fields'));
       return;
   }

   $section_id = sanitize_text_field($_POST['section_id']);
   $comment = sanitize_textarea_field($_POST['comment']);
   
   // Check if anonymous comments are allowed
   $allow_anonymous = get_option('sc_allow_anonymous');
   $user_id = get_current_user_id();
   
   if (!$user_id && !$allow_anonymous) {
       wp_send_json_error(array('message' => 'You must be logged in to comment'));
       return;
   }

   // Check for links if moderation is enabled
   $moderate_links = get_option('sc_moderate_links');
   $contains_links = preg_match('/(http|www)/i', $comment);
   $comment_approved = '1';
   
   if ($moderate_links && $contains_links) {
       $comment_approved = '0';
   } else if (get_option('sc_auto_approve_comments')) {
       $comment_approved = '1';
   } else {
       $comment_approved = '0';
   }

   $comment_author = $user_id ? wp_get_current_user()->display_name : 'Anonymous';
   $avatar_url = $user_id ? get_avatar_url($user_id) : get_avatar_url('anonymous@example.com');

   $comment_data = array(
       'comment_post_ID' => get_the_ID(),
       'comment_content' => $comment,
       'comment_type' => 'sectional_comment',
       'comment_approved' => $comment_approved,
       'user_id' => $user_id,
       'comment_author' => $comment_author,
       'comment_meta' => array(
           'section_id' => $section_id,
           'avatar_url' => $avatar_url
       )
   );

   $comment_id = wp_insert_comment($comment_data);
   
   if ($comment_id) {
       // Send notification email if enabled
       $notification_email = get_option('sc_notification_email');
       if ($notification_email) {
           $subject = 'New Sectional Comment';
           $message = sprintf(
               'New comment posted in section: %s\nAuthor: %s\nComment: %s',
               $section_id,
               $comment_author,
               $comment
           );
           wp_mail($notification_email, $subject, $message);
       }

       wp_send_json_success(array(
           'message' => 'Comment submitted successfully',
           'approved' => $comment_approved === '1'
       ));
   } else {
       wp_send_json_error(array('message' => 'Failed to submit comment'));
   }
}
add_action('wp_ajax_submit_sectional_comment', 'handle_submit_comment');
add_action('wp_ajax_nopriv_submit_sectional_comment', 'handle_submit_comment');

add_action('wp_ajax_delete_comment_box', 'handle_delete_comment_box');
function handle_delete_comment_box() {
    if (!check_ajax_referer('sectional_comments_admin_nonce', 'nonce', false)) {
        wp_send_json_error(array('message' => 'Invalid nonce'));
        return;
    }

    if (!current_user_can('manage_options')) {
        wp_send_json_error(array('message' => 'Insufficient permissions'));
        return;
    }

    $section_id = sanitize_text_field($_POST['section_id']);
    
    global $wpdb;
    $comments = get_comments(array(
        'meta_key' => 'section_id',
        'meta_value' => $section_id
    ));

    foreach ($comments as $comment) {
        wp_delete_comment($comment->comment_ID, true);
    }

    wp_send_json_success(array('message' => 'Comment box deleted successfully'));
}

// Retrieve comments for a section
function get_section_comments() {
   if (!check_ajax_referer('sectional_comments_nonce', 'nonce', false)) {
       wp_send_json_error(array('message' => 'Invalid nonce'));
       return;
   }
   
   if (!isset($_GET['section_id'])) {
       wp_send_json_error(array('message' => 'Missing section ID'));
       return;
   }

   $section_id = sanitize_text_field($_GET['section_id']);
   $page = isset($_GET['page']) ? intval($_GET['page']) : 1;
   $per_page = get_option('sc_comments_per_page', 5);

   $comments = get_comments(array(
       'type' => 'sectional_comment',
       'meta_key' => 'section_id',
       'meta_value' => $section_id,
       'order' => 'DESC',
       'orderby' => 'comment_date_gmt',
       'number' => $per_page,
       'offset' => ($page - 1) * $per_page,
       'status' => 'approve'
   ));

   $total_comments = get_comments(array(
       'type' => 'sectional_comment',
       'meta_key' => 'section_id',
       'meta_value' => $section_id,
       'count' => true,
       'status' => 'approve'
   ));

   $formatted_comments = array_map(function($comment) {
       return array(
           'id' => $comment->comment_ID,
           'content' => $comment->comment_content,
           'author' => $comment->comment_author,
           'date' => human_time_diff(strtotime($comment->comment_date)) . ' ago',
           'avatar_url' => get_comment_meta($comment->comment_ID, 'avatar_url', true)
       );
   }, $comments);
   
   wp_send_json_success(array(
       'comments' => $formatted_comments,
       'total_comments' => $total_comments,
       'has_more' => $total_comments > ($page * $per_page)
   ));
}
add_action('wp_ajax_get_section_comments', 'get_section_comments');
add_action('wp_ajax_nopriv_get_section_comments', 'get_section_comments');

// Shortcode function
function sectional_comments_shortcode($atts) {
   $atts = shortcode_atts(array(
       'id' => '',
       'title' => 'Comments'
   ), $atts, 'sectional_comments');

   $section_id = $atts['id'] ? $atts['id'] : generate_section_id();
   $title = $atts['title'];

   ob_start();
   ?>
   <div class="wp-block-sectional-comments-comment-block" data-section-id="<?php echo esc_attr($section_id); ?>">
       <h3><?php echo esc_html($title); ?></h3>
       <div class="comment-form">
           <form>
               <textarea name="comment" placeholder="Write your comment here" required></textarea>
               <div class="form-actions">
                   <button type="button" class="cancel-comment">Cancel</button>
                   <button type="submit" class="submit-comment">Submit Comment</button>
               </div>
           </form>
       </div>
       <div class="comment-list"></div>
   </div>
   <?php
   return ob_get_clean();
}
add_shortcode('sectional_comments', 'sectional_comments_shortcode');

// Generate unique section ID
function generate_section_id() {
   global $post;
   if ($post) {
       $slug = sanitize_title($post->post_title);
       return $slug . '-' . $post->ID;
   }
   return 'section-' . uniqid();
}

// Enable error logging
if (!function_exists('write_log')) {
   function write_log($log) {
       if (true === WP_DEBUG) {
           if (is_array($log) || is_object($log)) {
               error_log(print_r($log, true));
           } else {
               error_log($log);
           }
       }
   }
}